referrerpolicy=no-referrer-when-downgrade

ParaInfoOf

Type Alias ParaInfoOf 

pub type ParaInfoOf<T> = ParaInfo<<T as Config>::AccountId, <T as Config>::ReservationConsideration, <T as Config>::RegistrationConsideration, ProvidedBlockNumberOf<T>>;
The ParaInfo type as configured.

Aliased Type

pub struct ParaInfoOf<T> {
    pub manager: <T as Config>::AccountId,
    pub reservation: <T as Config>::ReservationConsideration,
    pub state: RegistrationState<<T as Config>::RegistrationConsideration, <<T as Config>::BlockNumberProvider as BlockNumberProvider>::BlockNumber>,
}

Fields

manager: <T as Config>::AccountId

The account that reserved the para id and controls it.

reservation: <T as Config>::ReservationConsideration

The [Consideration] ticket for the para id itself.

state: RegistrationState<<T as Config>::RegistrationConsideration, <<T as Config>::BlockNumberProvider as BlockNumberProvider>::BlockNumber>

Where this para id sits in the registration flow.